@@ -13,9 +13,10 @@
 ##############################################################################
 """Zope Version Tests
 
-$Id: test_zopeversion.py 107936 2010-01-09 14:58:15Z faassen $
+$Id: test_zopeversion.py 118999 2010-12-18 17:18:26Z mgedmin $
 """
 import os
+import sys
 import shutil
 import subprocess
 import tempfile
@@ -135,6 +136,10 @@ class Test(unittest.TestCase):
             # check that we don't get a 'Development/Unknown' version
             self.assert_(zv.result.startswith('Development/Revision: '))
 
+    def test_ZopeVersion_no_path_specified(self):
+        zopeVersion = ZopeVersion(None)
+        self.assertEqual(zopeVersion.result, "Meaningless")
+
 def test_suite():
     return unittest.makeSuite(Test)
 
